@@ -425,6 +425,16 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             """
             ...
 
+        @builtins.property
+        @jsii.member(jsii_name="orgunit")
+        def orgunit(self) -> typing.Optional[typing.List[str]]:
+            """``CfnPolicy.IEMapProperty.ORGUNIT``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-orgunit
+            """
+            ...
+
 
     class _IEMapPropertyProxy():
         """
@@ -442,6 +452,16 @@ class CfnPolicy(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monoc
             """
             return jsii.get(self, "account")
 
+        @builtins.property
+        @jsii.member(jsii_name="orgunit")
+        def orgunit(self) -> typing.Optional[typing.List[str]]:
+            """``CfnPolicy.IEMapProperty.ORGUNIT``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-iemap.html#cfn-fms-policy-iemap-orgunit
+            """
+            return jsii.get(self, "orgunit")
+
 
     @jsii.data_type(jsii_type="monocdk-experiment.aws_fms.CfnPolicy.PolicyTagProperty", jsii_struct_bases=[], name_mapping={'key': 'key', 'value': 'value'})
     class PolicyTagProperty():
